pub fn register_client_host(host_mesh: HostMeshRef)Expand description
Register the client host mesh from an external runtime (Python).
Called by Python’s bootstrap_host() so that try_this_host()
can discover C for the A/C invariant.
pub fn register_client_host(host_mesh: HostMeshRef)Register the client host mesh from an external runtime (Python).
Called by Python’s bootstrap_host() so that try_this_host()
can discover C for the A/C invariant.